function handles = tabplot(nX,nY,titleStr,xLabelStr,yLabelStr)
%
% function tabplot.m
%
% creates a tabular plot with uniform title, xlabel, and ylabel
%
%   nX = number of columns
%   nY = number of rows
%
%   titleStr  = title
%   xLabelStr = xlabel
%   yLabelStr = ylabel

figure;

axes('position',[0 0 1 1],'visible','off');
tT = text(0.5,0.93,titleStr,'fontsize',14,'HorizontalAlignment','center');  % title
tX = text(0.5,0.05,xLabelStr,'fontsize',14,'HorizontalAlignment','center'); % xlabel
tY = text(0.05,0.5,yLabelStr,'fontsize',14,'HorizontalAlignment','center',...
    'rotation',90);   % ylabel

if isempty(titleStr)
    PW = .74;   % plot width
    PH = .85;   % plot height
    XO = .01;   % x offset
    YO = .01;   % y offset
else
    PW = .74;   % plot width
    PH = .74;   % plot height
    XO = .01;   % x offset
    YO = .01;   % y offset
end    

XD = .01;   % x distance between single plots
YD = .01;   % y distance between single plots

SW = (PW-(nX-1)*XD)/nX; % single plot width
SH = (PH-(nY-1)*YD)/nY; % single plot height

for z = 1:nY
    for s = 1:nX
        X = PW-s*SW-(s-1)*XD+(1-PW)/2+XO;
        Y = PH-z*SH-(z-1)*YD+(1-PH)/2+YO;
        handles(s,z) = axes('position',[X Y SW SH]);
        if z < nY
            set(gca,'xticklabel',{});
        end
        if s < nX 
            set(gca,'yticklabel',{});
        end
    end
end

set(tX,'position',[X+(nX*SW+(nX-1)*XD)/2 3*Y/4 0]);
set(tY,'position',[X/4 Y+(nY*SH+(nY-1)*YD)/2 0]);

handles = flipud(handles)';