addpath('functions/');
addpath('msf/');

clear;
close(gcf);

% settings
velSD     = 6;
MinTrials = 20;         % minimum number of trials in a condition (e.g. Cue left)
timeLims  = [-399 899]; % temporal limits

% time windows for the analyses
W_PRECUE     = 1000;
W_POSTCUE    = 1000;
WINDOW_WIDTH = 200;
STEP_WIDTH   = 2;

LS = 'k-';              % line style
LW = 2;                 % line width

handles = tabplot(1,2,'', 'Time [ms]', 'Microsaccade rate [1/sec]');

zfid = fopen('subjects.vv','r');
outFile = 'spss/RateVV.txt';
fout = fopen(outFile,'w');
tiStr = 'VV';

vps_orirateRrechts = [];
vps_orirateRlinks  = [];
vps_orirateLrechts = [];
vps_orirateRlinks  = [];

cnt = 1;
s = 0;
while cnt ~= 0
    [vpcode, cnt] = fscanf(zfid,'%s',1);
    if cnt ~= 0
        mat = [];
        
        vpfile = sprintf('%s.msf%i',vpcode, velSD);
        
        if ~exist(vpfile)
            fprintf(1,'\n   File %s not existing!',vpfile);
        end
        
        fprintf(1,'\n\tloading %s ...',vpfile);
        mat = load(vpfile);
        % trial numbers for leftward and rightward
        [uni uniIdx] = unique(mat(:,1));
        idxR = find(mat(uniIdx,4) ==-1);
        idxL = find(mat(uniIdx,4) == 1);
        
        if length(idxR)>=MinTrials && length(idxL)>=MinTrials
            s = s+1;
            for side = -1:2:1   % -1 = Cue right; 1 = left
                % generate matrix of all MS and trials in that condition
                idx = mat(:,4)==side;
                cmat = mat(idx,:);
                
                % total number of trials in that condition
                nt = length(unique(cmat(:,1)));
                if side == -1
                    ntAll(1,s) = nt;
                elseif side == 1
                    ntAll(2,s) = nt;
                end
                
                % delete trials without saccades
                idx = cmat(:,11)==0;
                cmat(idx,:) = [];
                fprintf(1,'\n\t% i\t trials with %i\t microsaccades.',nt,size(cmat,1));
                
                % determine orientations of microsaccades
                % RIGHT VS. LEFT:
                phi = atan2(cmat(:,16),cmat(:,15));
                idx = phi>-pi/4 & phi<pi/4;
                MSrechts = cmat(idx,:);
                idx = find(phi>3/4*pi | phi<-3/4*pi);
                MSlinks = cmat(idx,:);
                
                % analyzing rate in moving time window
                scale = [];
                mw = 0;
                for t = (-W_PRECUE+WINDOW_WIDTH/2):STEP_WIDTH:(W_POSTCUE-WINDOW_WIDTH/2)
                    mw = mw + 1;
                    
                    w_beg = t-WINDOW_WIDTH/2;
                    w_end = t+WINDOW_WIDTH/2;
                    
                    idxMSwinrechts = find(MSrechts(:,12)>=w_beg & MSrechts(:,12)<w_end);
                    rateMSrechts(mw) = length(idxMSwinrechts)/nt;
                    
                    idxMSwinlinks = find(MSlinks(:,12)>=w_beg & MSlinks(:,12)<w_end);
                    rateMSlinks(mw) = length(idxMSwinlinks)/nt;
                    
                    scale = [scale; t];
                end
                if side == -1
                    vps_orirateRrechts(s,1:mw) = rateMSrechts*1000/WINDOW_WIDTH;
                    vps_orirateRlinks(s,1:mw) = rateMSlinks*1000/WINDOW_WIDTH;
                elseif side == 1
                    vps_orirateLrechts(s,1:mw) = rateMSrechts*1000/WINDOW_WIDTH;
                    vps_orirateLlinks(s,1:mw) = rateMSlinks*1000/WINDOW_WIDTH;
                end
            end
        end
    end
end

if strcmp(tiStr(1),'V')
    fillArea = [0 0 100 100];
else
    fillArea = [0 0 81 81];
end

% compute standard deviations
sdRrechts  = std(vps_orirateRrechts);
sdRlinks   = std(vps_orirateRlinks);
sdLrechts  = std(vps_orirateLrechts);
sdLlinks   = std(vps_orirateLlinks);

% compute standard errors
seRrechts  = sdRrechts/sqrt(size(vps_orirateRrechts,1)-1);
seRlinks   = sdRlinks/sqrt(size(vps_orirateRlinks,1)-1);
seLrechts  = sdLrechts/sqrt(size(vps_orirateLrechts,1)-1);
seLlinks   = sdLlinks/sqrt(size(vps_orirateLlinks,1)-1);

axes(handles(1,1));
hold on;
fill(fillArea,[0 3 3 0],[.5 .5 .5],'linestyle','none','facealpha',.3);
text(round(fillArea(3)/2),0.03,'CUE','fontsize',10,'fontweight','bold','rotation',90);
set(gca,'xgrid','on','Layer','top','fontsize',12,'ytick',linspace(0,3,16),'xtick',linspace(-1000,1000,11));
e1 = fill([scale' vecinv(scale)'],[(mean(vps_orirateLrechts)+seLrechts) vecinv(mean(vps_orirateLrechts)-seLrechts)],[.5 .5 .5],'linestyle','none','facealpha',.5);
e2 = fill([scale' vecinv(scale)'],[(mean(vps_orirateLlinks)+seLlinks) vecinv(mean(vps_orirateLlinks)-seLlinks)],[.5 .5 .5],'linestyle','none','facealpha',.5);
p1 = plot(scale,mean(vps_orirateLrechts),'k-','linewidth',2,'color',[0 0 0]);
p2 = plot(scale,mean(vps_orirateLlinks),'k--','linewidth',2,'color',[0 0 0]);
if 1 == 1
    legend([p1,p2],'Rightward', 'Leftward',2);
end
xlim(timeLims);
ylim([0 .9]);
text(timeLims(1)+60,.8,tiStr,'fontsize',14);

axes(handles(2,1));
hold on;
fill(fillArea,[0 3 3 0],[.5 .5 .5],'linestyle','none','facealpha',.3);
text(round(fillArea(3)/2),0.03,'CUE','fontsize',10,'fontweight','bold','rotation',90);
set(gca,'xgrid','on','Layer','top','fontsize',12,'ytick',linspace(0,3,16),'xtick',linspace(-1000,1000,11));
e1 = fill([scale' vecinv(scale)'],[(mean(vps_orirateRrechts)+seRrechts) vecinv(mean(vps_orirateRrechts)-seRrechts)],[.5 .5 .5],'linestyle','none','facealpha',.5);
e2 = fill([scale' vecinv(scale)'],[(mean(vps_orirateRlinks)+seRlinks) vecinv(mean(vps_orirateRlinks)-seRlinks)],[.5 .5 .5],'linestyle','none','facealpha',.5);
p1 = plot(scale,mean(vps_orirateRrechts),'k-','linewidth',2,'color',[0 0 0]);
p2 = plot(scale,mean(vps_orirateRlinks),'k--','linewidth',2,'color',[0 0 0]);
xlim(timeLims);
ylim([0 .9]);

fprintf('\n\nOK!\n');
